<?php
function bluemist_after_setup_theme() {
    global $content_width;

    if ( ! isset( $content_width ) )
        $content_width = 500;

    add_editor_style('editor-style.css');

    add_theme_support('automatic-feed-links');
    add_theme_support('post-thumbnails');
    add_theme_support('custom-header', array(
        'default-image' => get_template_directory_uri() . '/img/header.gif',
        'width'  => 770,
        'height' => 135,
        'default-text-color' => 'ffffff',
    ));
    add_theme_support('custom-background');
    add_theme_support('html5');

    register_nav_menu('main', 'Main navigation menu');
}
add_action('after_setup_theme', 'bluemist_after_setup_theme');

function bluemist_header_style() {
    ?><style type="text/css">
        <?php if (get_header_image()) : ?>
            #header {
                background: url(<?php header_image() ?>) 0 0 no-repeat;
            }
        <?php endif; ?>
        <?php if (get_header_textcolor()) : ?>
            #header h1 a,
            #header .description {
                color: #<?php header_textcolor();?>;
            }
        <?php endif; ?>

    </style><?php
}

add_action( 'widgets_init', 'bluemist_widgets_init' );
function bluemist_widgets_init() {
    register_sidebar( array(
        'name'          => 'Sidebar',
        'id'            => 'sidebar',
        'description'   => 'Right Sidebar',
        'before_title'  =>'<h3>',
        'after_title'   =>'</h3>',
        'before_widget' =>'<div class="box">',
        'after_widget'  =>'</div>'
    ) );
}

function bluemist_wp_enqueue_scripts() {
    wp_register_style('bluemist-ie', get_template_directory_uri().'/ie.css');

    wp_enqueue_style('bluemist-style', get_stylesheet_uri());

    $GLOBALS['wp_styles']->add_data( 'bluemist-ie', 'conditional', 'lte IE 8' );

    wp_enqueue_style( 'bluemist-ie' );

    if ( is_singular() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
}
add_action('wp_enqueue_scripts', 'bluemist_wp_enqueue_scripts');

function bluemist_remove_width_attribute( $html ) {
   $html = preg_replace( '/(width|height)="\d*"\s/', "", $html );
   return $html;
}
add_filter( 'post_thumbnail_html', 'bluemist_remove_width_attribute', 10 );
add_filter( 'image_send_to_editor', 'bluemist_remove_width_attribute', 10 );


function bluemist_wp_title( $title, $sep ) {
    global $paged, $page;

    if ( is_feed() ) {
        return $title;
    }

    // Add the site name.
    $title .= get_bloginfo( 'name' );

    // Add the site description for the home/front page.
    $site_description = get_bloginfo( 'description', 'display' );
    if ( $site_description && ( is_home() || is_front_page() ) ) {
        $title = "$title $sep $site_description";
    }

    // Add a page number if necessary.
    if ( $paged >= 2 || $page >= 2 ) {
        $title = "$title $sep " . sprintf( __( 'Page %s', 'twentyfourteen' ), max( $paged, $page ) );
    }

    return $title;
}
add_filter( 'wp_title', 'bluemist_wp_title', 10, 2 );
